import { Mime } from "../common/Mime";
import { StateMachineTransition } from "../common/StateMachineTransition";
import { DtoFieldMetadata } from "../dto/DtoFieldMetadata";
export interface ModelFieldMetadata extends DtoFieldMetadata {
    /**
     * Whether this field is primary key.
     */
    primaryKeyProps?: {
        /**
         * Auto-incrementing PK, default to true if omitted.
         */
        isAutoIncrement?: boolean;
    };
    foreignKeyProps?: {
        /**
         * Id of the model to refer as foreign key.
         */
        id: string;
        /**
         * Whether to cascade on delete.
         */
        cascade?: boolean;
    };
    indexingProps?: {
        groups: string[];
    };
    uniqueProps?: {
        groupName?: string;
    };
    /**
     * Whether current field is timestamp
     */
    isTimestamp?: boolean;
    /**
     * Whether to store this as 64-bit big integer.
     */
    isBigInt?: boolean;
    /**
     * Whether to use TEXT to store the string value at provided length.
     */
    textLength?: number;
    /**
     * This value is generated from server and must not be supplied from client.
     */
    serverValue?: boolean;
    /**
     * Mime type for better client-side rendering.
     */
    mimeType?: Mime;
    /**
     * State machine to validate for transition.
     */
    stateMachineTransition?: StateMachineTransition<any>[];
    /**
     * Allow regex search in this field and other fields that has searchable is true.
     */
    searchable?: boolean;
    /**
     * Whether the server modifies this fields before inserting into database.
     */
    serverModifyFn?: (value: any) => any;
    /**
     * Case sensitive for searching.
     */
    caseSensitive?: boolean;
    /**
     * Accent sensitive for searching.
     */
    accentSensitive?: boolean;
    /**
     * Whether this field is used to display in dropdown.
     */
    isLabel?: boolean;
}
//# sourceMappingURL=ModelFieldMetadata.d.ts.map